@@ -6,11 +6,14 @@ import errno
 import importlib.machinery
 import os
 import shutil
+import string
+import tarfile
 import types
 
 import git
 import semantic_version as semver
 
+
 def make_dir(path):
     """Create a directory or do nothing if it already exists.
 
@@ -30,7 +33,7 @@ def normalize_version_tag(tag):
     """Given version string "vX.Y.Z", returns "X.Y.Z".
     Returns other input strings unchanged.
     """
-    if len(tag) > 1 and tag[0] == 'v' and tag[1].isdigit():
+    if len(tag) > 1 and tag[0] == "v" and tag[1].isdigit():
         return tag[1:]
 
     return tag
@@ -66,11 +69,44 @@ def make_symlink(target_path, link_path, force=True):
             raise error
 
 
+def safe_tarfile_extractall(tfile, destdir):
+    """Wrapper to tarfile.extractall(), checking for path traversal.
+
+    This adds the safeguards the Python docs for tarfile.extractall warn about:
+
+    Never extract archives from untrusted sources without prior inspection. It
+    is possible that files are created outside of path, e.g. members that have
+    absolute filenames starting with "/" or filenames with two dots "..".
+
+    Args:
+        tfile (str): the tar file to extract
+
+        destdir (str): the destination directory into which to place contents
+
+    Raises:
+        Exception: if the tarfile would extract outside destdir
+    """
+
+    def is_within_directory(directory, target):
+        abs_directory = os.path.abspath(directory)
+        abs_target = os.path.abspath(target)
+        prefix = os.path.commonprefix([abs_directory, abs_target])
+        return prefix == abs_directory
+
+    with tarfile.open(tfile) as tar:
+        for member in tar.getmembers():
+            member_path = os.path.join(destdir, member.name)
+            if not is_within_directory(destdir, member_path):
+                raise Exception("attempted path traversal in tarfile")
+
+        tar.extractall(destdir)
+
+
 def find_sentence_end(s):
     beg = 0
 
     while True:
-        period_idx = s.find('.', beg)
+        period_idx = s.find(".", beg)
 
         if period_idx == -1:
             return -1
@@ -89,21 +125,23 @@ def find_sentence_end(s):
 def git_clone(git_url, dst_path, shallow=False):
     if shallow:
         try:
-            git.Git().clone(git_url, dst_path, '--no-single-branch', recursive=True, depth=1)
+            git.Git().clone(
+                git_url, dst_path, "--no-single-branch", recursive=True, depth=1
+            )
         except git.exc.GitCommandError:
-            if not git_url.startswith('.') and not git_url.startswith('/'):
+            if not git_url.startswith(".") and not git_url.startswith("/"):
                 # Not a local repo
                 raise
 
-            if not os.path.exists(os.path.join(git_url, '.git', 'shallow')):
+            if not os.path.exists(os.path.join(git_url, ".git", "shallow")):
                 raise
 
             # Some git versions cannot clone from a shallow-clone, so copy
             # and reset/clean it to a pristine condition.
             copy_over_path(git_url, dst_path)
             rval = git.Repo(dst_path)
-            rval.git.reset('--hard')
-            rval.git.clean('-ffdx')
+            rval.git.reset("--hard")
+            rval.git.clean("-ffdx")
     else:
         git.Git().clone(git_url, dst_path, recursive=True)
 
@@ -116,7 +154,7 @@ def git_clone(git_url, dst_path, shallow=False):
     # fetching from a remote location (e.g.  when unbundling).  This
     # unintended inheritence of "origin" seems to only happen when cloning a
     # local git repo that has submodules ?
-    rval.git.remote('set-url', 'origin', git_url)
+    rval.git.remote("set-url", "origin", git_url)
     return rval
 
 
@@ -132,8 +170,8 @@ def git_checkout(clone, version):
         git.exc.GitCommandError: if the git repo is invalid
     """
     clone.git.checkout(version)
-    clone.git.submodule('sync', '--recursive')
-    clone.git.submodule('update', '--recursive', '--init')
+    clone.git.submodule("sync", "--recursive")
+    clone.git.submodule("update", "--recursive", "--init")
 
 
 def git_default_branch(repo):
@@ -152,7 +190,7 @@ def git_default_branch(repo):
     """
 
     try:
-        remote = repo.remote('origin')
+        remote = repo.remote("origin")
     except ValueError:
         remote = None
 
@@ -160,24 +198,24 @@ def git_default_branch(repo):
         # Technically possible that remote has no HEAD, so guard against that.
         try:
             head_ref_name = remote.refs.HEAD.ref.name
-        except:
+        except Exception:
             head_ref_name = None
 
         if head_ref_name:
-            remote_prefix = 'origin/'
+            remote_prefix = "origin/"
 
             if head_ref_name.startswith(remote_prefix):
-                return head_ref_name[len(remote_prefix):]
+                return head_ref_name[len(remote_prefix) :]
 
             return head_ref_name
 
     ref_names = [ref.name for ref in repo.refs]
 
-    if 'main' in ref_names:
-        return 'main'
+    if "main" in ref_names:
+        return "main"
 
-    if 'master' in ref_names:
-        return 'master'
+    if "master" in ref_names:
+        return "master"
 
     try:
         # See if there's a branch currently checked out
@@ -216,8 +254,8 @@ def git_pull(repo):
         git.exc.GitCommandError: in case of git trouble
     """
     repo.git.pull()
-    repo.git.submodule('sync', '--recursive')
-    repo.git.submodule('update', '--recursive', '--init')
+    repo.git.submodule("sync", "--recursive")
+    repo.git.submodule("update", "--recursive", "--init")
 
 
 def git_remote_urls(repo):
@@ -229,13 +267,13 @@ def git_remote_urls(repo):
     cases. We use the config subsystem to query the URLs directly -- one of the
     fallback mechanisms in GitPython's Remote.urls() implementation.
     """
-    remote_details = repo.git.config('--get-regexp', 'remote\..+\.url')
+    remote_details = repo.git.config("--get-regexp", r"remote\..+\.url")
     remotes = {}
 
-    for line in remote_details.split('\n'):
+    for line in remote_details.split("\n"):
         try:
             remote, url = line.split(maxsplit=1)
-            remote = remote.split('.')[1]
+            remote = remote.split(".")[1]
             remotes[remote] = url
         except (ValueError, IndexError):
             pass
@@ -245,17 +283,13 @@ def git_remote_urls(repo):
 
 def is_sha1(s):
     if not s:
-        return False;
+        return False
 
     if len(s) != 40:
         return False
 
-    for c in s:
-        if c not in {'a', 'b', 'c', 'd', 'e', 'f',
-                     '0', '1', '2', '3', '4', '5', '6', '7', '8', '9'}:
-            return False
-
-    return True
+    hexdigits = set(string.hexdigits.lower())
+    return all(c in hexdigits for c in s)
 
 
 def is_exe(path):
@@ -266,7 +300,7 @@ def find_program(prog_name):
     path, _ = os.path.split(prog_name)
 
     if path:
-        return prog_name if is_exe(prog_name) else ''
+        return prog_name if is_exe(prog_name) else ""
 
     for path in os.environ["PATH"].split(os.pathsep):
         path = os.path.join(path.strip('"'), prog_name)
@@ -274,7 +308,8 @@ def find_program(prog_name):
         if is_exe(path):
             return path
 
-    return ''
+    return ""
+
 
 def std_encoding(stream):
     if stream.encoding:
@@ -283,30 +318,37 @@ def std_encoding(stream):
     import locale
 
     if locale.getdefaultlocale()[1] is None:
-        return 'utf-8'
+        return "utf-8"
 
     return locale.getpreferredencoding()
 
+
 def read_zeek_config_line(stdout):
     return stdout.readline().strip()
 
 
 def get_zeek_version():
-    zeek_config = find_program('zeek-config')
+    zeek_config = find_program("zeek-config")
 
     if not zeek_config:
-        zeek_config = find_program('bro-config')
+        zeek_config = find_program("bro-config")
 
     if not zeek_config:
-        return ''
+        return ""
 
     import subprocess
-    cmd = subprocess.Popen([zeek_config, '--version'],
-                           stdout=subprocess.PIPE, stderr=subprocess.STDOUT,
-                           bufsize=1, universal_newlines=True)
+
+    cmd = subprocess.Popen(
+        [zeek_config, "--version"],
+        stdout=subprocess.PIPE,
+        stderr=subprocess.STDOUT,
+        bufsize=1,
+        universal_newlines=True,
+    )
 
     return read_zeek_config_line(cmd.stdout)
 
+
 def load_source(filename):
     """Loads given Python script from disk.
 
@@ -323,12 +365,13 @@ def load_source(filename):
 
     # Naming here is unimportant, since we access members of the new
     # module via the returned instance.
-    loader = importlib.machinery.SourceFileLoader('template_' + dirname, absname)
+    loader = importlib.machinery.SourceFileLoader("template_" + dirname, absname)
     mod = types.ModuleType(loader.name)
     loader.exec_module(mod)
 
     return mod
 
+
 def configparser_section_dict(parser, section):
     """Returns a dict representing a ConfigParser section.
 
